
# Google Mail MCP Server

An MCP Server for the Google Mail API.

## Supported Integrations

- AgentR
- API Key (Coming Soon)
- OAuth (Coming Soon)

## Tools

This is automatically generated from OpenAPI schema for the Google Mail API.

## Supported Integrations

This tool can be integrated with any service that supports HTTP requests.

## Tool List

| Tool | Description |
|------|-------------|
| create_draft | Create a draft email |
| create_label | Create a new Gmail label |
| get_draft | Get a specific draft email by ID |
| get_message | Get a specific email message by ID |
| get_profile | Retrieve the user's Gmail profile information. |
| list_drafts | List drafts in the user's mailbox |
| list_labels | List all labels in the user's Gmail account |
| list_messages | List messages in the user's mailbox |
| send_draft | Send an existing draft email |
| send_email | Send an email |
| validate | Function for validate |



## Usage

- Login to AgentR
- Follow the quickstart guide to setup MCP Server for your client
- Visit Apps Store and enable the Google Mail app
- Restart the MCP Server

### Local Development

- Follow the README to test with the local MCP Server
